def sumSimple(num1,num2):
    return num1 + num2

def restSimple(num1,num2):
    return num1 - num2    

def multSimple(num1,num2):
    return num1 * num2    